@@ -2,9 +2,9 @@ package Business::CyberSource::Response;
 use strict;
 use warnings;
 use namespace::autoclean;
-use Module::Load qw( load );
+use Module::Load 'load';
 
-our $VERSION = '0.007004'; # TRIAL VERSION
+our $VERSION = '0.007005'; # TRIAL VERSION
 
 use Moose;
 extends 'Business::CyberSource::Message';
@@ -350,7 +350,7 @@ Business::CyberSource::Response - Response Object
 
 =head1 VERSION
 
-version 0.007004
+version 0.007005
 
 =head1 SYNOPSIS
 
